@@ -479,11 +479,11 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.Gist.Gist`
         """
         assert isinstance(public, bool), public
-        assert all(isinstance(element, github.InputFileContent) for element in files.values()), files
+        assert all(isinstance(element, github.InputFileContent) for element in iter(files.values())), files
         assert description is github.GithubObject.NotSet or isinstance(description, str), description
         post_parameters = {
             "public": public,
-            "files": dict((key, value._identity) for key, value in files.items()),
+            "files": dict((key, value._identity) for key, value in iter(files.items())),
         }
         if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
