@@ -247,12 +247,12 @@ class Gist(github.GithubObject.CompletableGithubObject):
         :rtype: None
         """
         assert description is github.GithubObject.NotSet or isinstance(description, str), description
-        assert files is github.GithubObject.NotSet or all(element is None or isinstance(element, github.InputFileContent) for element in files.values()), files
+        assert files is github.GithubObject.NotSet or all(element is None or isinstance(element, github.InputFileContent) for element in iter(files.values())), files
         post_parameters = dict()
         if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         if files is not github.GithubObject.NotSet:
-            post_parameters["files"] = dict((key, None if value is None else value._identity) for key, value in files.items())
+            post_parameters["files"] = dict((key, None if value is None else value._identity) for key, value in iter(files.items()))
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
