@@ -199,8 +199,8 @@ class GithubObject(object):
             return _BadAttribute(value, [dict])
 
     def _makeDictOfStringsToClassesAttribute(self, klass, value):
-        if isinstance(value, dict) and all(isinstance(key, str) and isinstance(element, dict) for key, element in value.items()):
-            return _ValuedAttribute(dict((key, klass(self._requester, self._headers, element, completed=False)) for key, element in value.items()))
+        if isinstance(value, dict) and all(isinstance(key, str) and isinstance(element, dict) for key, element in iter(value.items())):
+            return _ValuedAttribute(dict((key, klass(self._requester, self._headers, element, completed=False)) for key, element in iter(value.items())))
         else:
             return _BadAttribute(value, {(str, str): dict})
 
